translate.misc.ini.LineType

Package translate :: Package misc :: Module ini :: Class LineType |
[hide private]
[frames] | no frames]

# Class LineType

source code

Instance Methods | [hide private]
__init__(self, line=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__str__(self) str(x) | source code
__setattr__(self, name, value) x.__setattr__('name', value) <==> x.name = value | source code
to_string(self) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
| line = `None` hash(x)

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, line=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### __setattr__(self, name, value) | source code
x.__setattr__('name', value) <==> x.name = value Overrides: object.__setattr__ (inherited documentation)